@@ -203,9 +203,9 @@ class CompileOptions {
         [](void* user_data, const char* requested_source, int type,
            const char* requesting_source, size_t include_depth) {
           auto* sub_includer = static_cast<IncluderInterface*>(user_data);
-          return sub_includer->GetInclude(requested_source,
-                                      (shaderc_include_type)type,
-                                      requesting_source, include_depth);
+          return sub_includer->GetInclude(
+              requested_source, static_cast<shaderc_include_type>(type),
+              requesting_source, include_depth);
         },
         [](void* user_data, shaderc_include_result* include_result) {
           auto* sub_includer = static_cast<IncluderInterface*>(user_data);
@@ -274,6 +274,13 @@ class CompileOptions {
     shaderc_compile_options_set_auto_bind_uniforms(options_, auto_bind);
   }
 
+  // Sets whether the compiler should automatically remove sampler variables
+  // and convert image variables to combined image sampler variables.
+  void SetAutoSampledTextures(bool auto_sampled) {
+    shaderc_compile_options_set_auto_combined_image_sampler(options_,
+                                                            auto_sampled);
+  }
+
   // Sets whether the compiler should use HLSL IO mapping rules for bindings.
   // Defaults to false.
   void SetHlslIoMapping(bool hlsl_iomap) {
@@ -304,6 +311,12 @@ class CompileOptions {
                                                        kind, base);
   }
 
+  // Sets whether the compiler should preserve all bindings, even when those
+  // bindings are not used.
+  void SetPreserveBindings(bool preserve_bindings) {
+    shaderc_compile_options_set_preserve_bindings(options_, preserve_bindings);
+  }
+
   // Sets whether the compiler automatically assigns locations to
   // uniform variables that don't have explicit locations.
   void SetAutoMapLocations(bool auto_map) {
@@ -335,6 +348,11 @@ class CompileOptions {
     shaderc_compile_options_set_hlsl_functionality1(options_, enable);
   }
 
+  // Sets whether 16-bit types are supported in HLSL or not.
+  void SetHlsl16BitTypes(bool enable) {
+    shaderc_compile_options_set_hlsl_16bit_types(options_, enable);
+  }
+
   // Sets whether the compiler should invert position.Y output in vertex shader.
   void SetInvertY(bool enable) {
     shaderc_compile_options_set_invert_y(options_, enable);
